==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/cmd/xtheader.c <==
/*============================================================================*/
/* ѹ                                                                   */
/*----------------------------------------------------------------------------*/
/* 1.0 : APIб                                                      */
/*============================================================================*/
  
#include <musashi.h>
#include <stdlib.h>

#include <xtheaderHelp.h>
struct mssComHelp comHelp={
  "xtheader",     /* ޥ̾       */
  "1.0",          /* С       */
  HELPT,          /* ޥɥȥ */
  HELPS,          /*              */
  HELPE,          /*            */
  HELPR,          /* ȥޥ     */
  HELPA,          /* Ծ         */                                      
  HELPB,          /* ХݡȾ */
  HELPH           /* ۡڡ     */
}; 

extern struct mssGlobalVariables mssGV;

int main(int argc, char *argv[]){
/*============================================================================*/
/* ץ                                                       */
/*============================================================================*//*----------------------------------------------------------------------------*/
/* ̾                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptSLS optFNM={
    OSLS,   /* ץ󥿥                                             */
    "a",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    NULL,   /* ǥե(ʸ)                                           */
    MssFieldMaxCnt, /* ޤǶڤǿκ                     */
    1,      /* ǤʸĹκǾ                                     */
    MssFieldNameMaxLen,/* ǤʸĹκ                          */
    0,      /* 1:Ǥ˥Ǥ,0:Բ  ex) aaaa:xxxxx            */
    FNMT,   /* ΥץΥȥ(Helpɽ)                         */
    FNMC    /* ΥץΥ(Helpɽ)                         */
  }; 

/*----------------------------------------------------------------------------*/
/* ȥ                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptSTR optTIT={
    OSTR,   /* ץ󥿥                                             */
    "l",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    NULL,   /* ǥե                                                   */
    0,      /* ʸκǾĹ                                               */
    MssTitleMaxLen,/* ʸκĹ                                        */
    TITT,   /* ΥץΥȥ(Helpɽ)                         */
    TITC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/*                                                                    */
/*----------------------------------------------------------------------------*/
  MssOptSTR optCOM={
    OSTR,   /* ץ󥿥                                             */
    "c",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    NULL,   /* ǥե                                                   */
    0,      /* ʸκǾĹ                                               */
    MssCommentMaxLen,/* ʸκĹ                                      */
    COMT,   /* ΥץΥȥ(Helpɽ)                         */
    COMC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ݡȥե                                                         */
/*----------------------------------------------------------------------------*/
  MssOptINF optIMP={
    OINF,   /* ץ󥿥                                             */
    "I",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    1,      /* ǽκե                                     */
    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
    IMPT,   /* ΥץΥȥ(Helpɽ)                         */
    IMPC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ȥ                                                             */
/*----------------------------------------------------------------------------*/
  MssOptFLG optSRT={
    OFLG,   /* ץ󥿥                                             */
    "S",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    SRTT,   /* ΥץΥȥ(Helpɽ)                         */
    SRTC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptINF optINF={
    OINF,   /* ץ󥿥                                             */
    "i",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    1,      /* ǽκե                                     */
    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
    INFT,   /* ΥץΥȥ(Helpɽ)                         */
    INFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptOTF optOTF={
    OOTF,   /* ץ󥿥                                             */
    "o",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
    OTFC    /* ΥץΥ(Helpɽ)                         */
  };
    
/*----------------------------------------------------------------------------*/
/* ̽                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLG optZIP={
    OFLG,   /* ץ󥿥                                             */
    "z",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    ZIPT,   /* ΥץΥȥ(Helpɽ)                         */
    ZIPC    /* ΥץΥ(Helpɽ)                         */
  };
    

/*----------------------------------------------------------------------------*/
/* ץޤȤ                                                       */
/*----------------------------------------------------------------------------*/
  void *opt[]={&optFNM,&optTIT,&optCOM,&optIMP,&optSRT,
               &optINF,&optOTF,&optZIP,NULL};

/*============================================================================*/
/* ѿ                                                             */
/*============================================================================*/
  struct mssHeader *hdi; /*ƥȥե<head>Ǽ¤*/
  struct mssHeader *hdI; /*-Iϥե<head>Ǽ¤*/
  struct mssHeader *hdo; /*ϥե<head>Ǽ¤*/
  struct mssFPR    *fpr; /*ϥե빽¤*/
  struct mssFPR    *fpr2;/*ݡȥե빽¤*/
  struct mssFPW    *fpw; /*ϥե빽¤*/
  struct mssRec    *rec; /*-ԥХåե¤*/

/*----------------------------------------------------------------------------*/
/*                                                                      */
/*----------------------------------------------------------------------------*/
  mssInit(argc,argv,&comHelp);       /* ʥʤɤν              */
  mssHelpDoc(opt,&comHelp,argc,argv);/* إ                                */
  mssSetOption(opt,argc,argv);       /* ޥɥץ              */
  fpr=mssOpenFPR(optINF.str,4);      /* ϥե륪ץ                  */
  hdi=mssReadHeader(fpr);            /* إåɤ߹                      */

  /*-a,-IꤵȤ*/
  if(optIMP.set && optFNM.set){
    mssShowErrMsg("choose one option from -a or -I");
    mssEnd(mssErrorNoDefault);
  }

/*----------------------------------------------------------------------------*/
/*ϥإåκȽ                                                    */
/*----------------------------------------------------------------------------*/
  if(optIMP.set){ /*-Iե饰on*/
    fpr2=mssOpenFPR(optIMP.str,4);   /*ݡȥե륪ץ*/
    hdI=mssReadHeader(fpr2);         /*̾ɤ߹*/

    /*ϥإåν(ȥΥԡ)*/
    hdo=mssInitCpyHeader(hdI);

    /*ϥإåܤɲ*/
    mssAddFieldsByFields(hdo->flds,hdI->flds);

    if(!optSRT.set){
      /*ȾΥꥢ*/
      mssClearFieldsSort(hdo->flds);
    }
    mssCloseFPR(fpr2);               /*ݡȥե륯*/

  }else if(optFNM.set) {
    /*ϥإåν(ȥΥԡ)*/
    hdo=mssInitCpyHeader(hdi);

    /* -aǻꤵ줿̾ɲä*/
    mssAddFieldsByStrList(hdo->flds,optFNM.strList,optFNM.cnt);

  }else{
    /*ϥإåν(ȥΥԡ)*/
    hdo=mssInitCpyHeader(hdi);

    /*ϥإåܤɲ*/
    mssAddFieldsByFields(hdo->flds,hdi->flds);
  }

  if(hdo->flds->cnt != hdi->flds->cnt){
    mssShowErrMsg("the numbers of fields mismatch");
    mssEnd(mssErrorNoDefault);
  }

  /*-lե饰on*/
  if(optTIT.set){
    mssFree(hdo->title);
    hdo->title  = mssStrdup(optTIT.str);
  }

  /*-cե饰on*/
  if(optCOM.set){
    mssFree(hdo->comment);
    hdo->comment = mssStrdup(optCOM.str);
  }

  /*ɸϥץ+إåν*/
  fpw=mssOpenFPW(optOTF.str,optZIP.set,0);
  mssWriteHeader(hdo,fpw);

/*----------------------------------------------------------------------------*/
/*ᥤ롼                                                              */
/*----------------------------------------------------------------------------*/
  rec=mssInitRec();
  while(EOF != mssReadRec(fpr,rec)){
    mssGV.inCnt++;
    mssWriteStr(rec->pnt,fpw);
    mssWriteRet(fpw);
    mssGV.outCnt++;
  } 
  mssFreeRec(rec);

/*----------------------------------------------------------------------------*/
/*եå&λ                                                       */
/*----------------------------------------------------------------------------*/
  mssWriteFooter(fpw);    /* եåν             */
  mssCloseFPR(fpr);       /* ϥեΥ     */
  mssCloseFPW(fpw);       /* ϥեΥ     */
  mssFreeHeader(hdi);     /* ϥإåΰ賫         */
  mssFreeHeader(hdo);     /* ϥإåΰ賫         */
  mssFreeOption(opt);     /* ץΰ賫         */
  mssShowEndMsg();        /* λå             */
  mssEnd(mssExitSuccess); /* λ                       */
  return(0);              /* to avoid warning message   */
}

==> musashi-core-1.0.4.tar.gz: musashi-core-1.0.4/cmd/xtheader.c <==
/*============================================================================*/
/* ѹ                                                                   */
/*----------------------------------------------------------------------------*/
/* 1.0 : APIб                                                      */
/* 1.1 : 2004/08/24 -fץɲ                                          */
/*============================================================================*/
  
#include <musashi.h>
#include <stdlib.h>

#include <xtheaderHelp.h>
struct mssComHelp comHelp={
  "xtheader",     /* ޥ̾       */
  "1.1",          /* С       */
  HELPT,          /* ޥɥȥ */
  HELPS,          /*              */
  HELPE,          /*            */
  HELPR,          /* ȥޥ     */
  HELPA,          /* Ծ         */                                      
  HELPB,          /* ХݡȾ */
  HELPH           /* ۡڡ     */
}; 

extern struct mssGlobalVariables mssGV;

int main(int argc, char *argv[]){
/*============================================================================*/
/* ץ                                                       */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ̾                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptSLS optFNM={
    OSLS,   /* ץ󥿥                                             */
    "a",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    NULL,   /* ǥե(ʸ)                                           */
    MssFieldMaxCnt, /* ޤǶڤǿκ                     */
    1,      /* ǤʸĹκǾ                                     */
    MssFieldNameMaxLen,/* ǤʸĹκ                          */
    0,      /* 1:Ǥ˥Ǥ,0:Բ  ex) aaaa:xxxxx            */
    FNMT,   /* ΥץΥȥ(Helpɽ)                         */
    FNMC    /* ΥץΥ(Helpɽ)                         */
  }; 

/*----------------------------------------------------------------------------*/
/* ̾ʬŪѹ                                                       */
/*----------------------------------------------------------------------------*/
  MssOptFLD optFLD={
    OFLD,   /* ץ󥿥                                             */
    "f",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    MssFieldMaxCnt, /* ǽʺܿ                                 */
    "i",    /* оݤȤϥǡΥ(GUI)                  */
    1,      /* ɽĤ뤫ɤ(0:Բ,1:)                      */
    1,      /* ̾Ǥ뤫ɤ(0:Բ,1:)                    */
    NULL,   /* ܥץ(%ʲ)ǻǽʸ                        */
            /* ex) ԲĤξNULL, "nr": "-f ̾%rn"λǽ     */
    FLDT,   /* ΥץΥȥ(Helpɽ)                         */
    FLDC,   /* ΥץΥ(Helpɽ)                         */
    FLDF    /* ե饰ˤĤƤ(Helpɽ)ʣξϥޤǶڤ   */
  };

/*----------------------------------------------------------------------------*/
/* ȥ                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptSTR optTIT={
    OSTR,   /* ץ󥿥                                             */
    "l",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    NULL,   /* ǥե                                                   */
    0,      /* ʸκǾĹ                                               */
    MssTitleMaxLen,/* ʸκĹ                                        */
    TITT,   /* ΥץΥȥ(Helpɽ)                         */
    TITC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/*                                                                    */
/*----------------------------------------------------------------------------*/
  MssOptSTR optCOM={
    OSTR,   /* ץ󥿥                                             */
    "c",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ, 2:XMLtableǤΤɬ(txtǤ̵)      */
    NULL,   /* ǥե                                                   */
    0,      /* ʸκǾĹ                                               */
    MssCommentMaxLen,/* ʸκĹ                                      */
    COMT,   /* ΥץΥȥ(Helpɽ)                         */
    COMC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ݡȥե                                                         */
/*----------------------------------------------------------------------------*/
  MssOptINF optIMP={
    OINF,   /* ץ󥿥                                             */
    "I",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    1,      /* ǽκե                                     */
    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
    IMPT,   /* ΥץΥȥ(Helpɽ)                         */
    IMPC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ȥ                                                             */
/*----------------------------------------------------------------------------*/
  MssOptFLG optSRT={
    OFLG,   /* ץ󥿥                                             */
    "S",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    SRTT,   /* ΥץΥȥ(Helpɽ)                         */
    SRTC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptINF optINF={
    OINF,   /* ץ󥿥                                             */
    "i",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    1,      /* ǽκե                                     */
    0,      /*1:file not foundΥ顼ǽλʤ 0:                   */
    INFT,   /* ΥץΥȥ(Helpɽ)                         */
    INFC    /* ΥץΥ(Helpɽ)                         */
  };

/*----------------------------------------------------------------------------*/
/* ϥե                                                               */
/*----------------------------------------------------------------------------*/
  MssOptOTF optOTF={
    OOTF,   /* ץ󥿥                                             */
    "o",    /* (ʣʸԲ)                                   */
    0,      /* 0:ץ, 1:ɬ                                         */
    OTFT,   /* ΥץΥȥ(Helpɽ)                         */
    OTFC    /* ΥץΥ(Helpɽ)                         */
  };
    
/*----------------------------------------------------------------------------*/
/* ̽                                                                   */
/*----------------------------------------------------------------------------*/
  MssOptFLG optZIP={
    OFLG,   /* ץ󥿥                                             */
    "z",    /* (ʣʸԲ)                                   */
    0,      /* ǥե(Ūˤ0) onˤȤ1ˤ          */
    ZIPT,   /* ΥץΥȥ(Helpɽ)                         */
    ZIPC    /* ΥץΥ(Helpɽ)                         */
  };
    

/*----------------------------------------------------------------------------*/
/* ץޤȤ                                                       */
/*----------------------------------------------------------------------------*/
  void *opt[]={&optFNM,&optFLD,&optTIT,&optCOM,&optIMP,&optSRT,
               &optINF,&optOTF,&optZIP,NULL};

/*============================================================================*/
/* ѿ                                                             */
/*============================================================================*/
  struct mssHeader *hdi; /*ƥȥե<head>Ǽ¤*/
  struct mssHeader *hdI; /*-Iϥե<head>Ǽ¤*/
  struct mssHeader *hdo; /*ϥե<head>Ǽ¤*/
  struct mssFPR    *fpr; /*ϥե빽¤*/
  struct mssFPR    *fpr2;/*ݡȥե빽¤*/
  struct mssFPW    *fpw; /*ϥե빽¤*/
  struct mssRec    *rec; /*-ԥХåե¤*/

/*----------------------------------------------------------------------------*/
/*                                                                      */
/*----------------------------------------------------------------------------*/
  mssInit(argc,argv,&comHelp);       /* ʥʤɤν              */
  mssHelpDoc(opt,&comHelp,argc,argv);/* إ                                */
  mssSetOption(opt,argc,argv);       /* ޥɥץ              */
  fpr=mssOpenFPR(optINF.str,4);      /* ϥե륪ץ                  */
  hdi=mssReadHeader(fpr);            /* إåɤ߹                      */
  mssSetOptFld(&optFLD, hdi);        /* -f ܤإåܤ˴ϢŤ     */

  /*-f,-a,-I2İʾꤵȤ*/
  if(optIMP.set + optFNM.set + optFLD.set > 1){
    mssShowErrMsg("option -f, -a and -I are exclusive");
    mssEnd(mssErrorNoDefault);
  }

/*----------------------------------------------------------------------------*/
/*ϥإåκȽ                                                    */
/*----------------------------------------------------------------------------*/
  if(optIMP.set){ /*-Iե饰on*/
    fpr2=mssOpenFPR(optIMP.str,4);   /*ݡȥե륪ץ*/
    hdI=mssReadHeader(fpr2);         /*̾ɤ߹*/

    /*ϥإåν(ȥΥԡ)*/
    hdo=mssInitCpyHeader(hdI);

    /*ϥإåܤɲ*/
    mssAddFieldsByFields(hdo->flds,hdI->flds);

    if(!optSRT.set){
      /*ȾΥꥢ*/
      mssClearFieldsSort(hdo->flds);
    }
    mssCloseFPR(fpr2);               /*ݡȥե륯*/

  }else if(optFNM.set) {
    /*ϥإåν(ȥΥԡ)*/
    hdo=mssInitCpyHeader(hdi);

    /* -aǻꤵ줿̾ɲä*/
    mssAddFieldsByStrList(hdo->flds,optFNM.strList,optFNM.cnt);

  }else if(optFLD.set) {
    /*ϥإåν(ȥΥԡ)*/
    hdo=mssInitCpyHeader(hdi);

    /*-fǻꤵ줿ܤ-f顢¾ϥإåܤɲä*/
    mssAddHeadOrOptFields(hdo->flds,hdi,&optFLD);

  }else{
    /*ϥإåν(ȥΥԡ)*/
    hdo=mssInitCpyHeader(hdi);

    /*ϥإåܤɲ*/
    mssAddFieldsByFields(hdo->flds,hdi->flds);
  }

  if(hdo->flds->cnt != hdi->flds->cnt){
    mssShowErrMsg("the numbers of fields mismatch");
    mssEnd(mssErrorNoDefault);
  }

  /*-lե饰on*/
  if(optTIT.set){
    mssFree(hdo->title);
    hdo->title  = mssStrdup(optTIT.str);
  }

  /*-cե饰on*/
  if(optCOM.set){
    mssFree(hdo->comment);
    hdo->comment = mssStrdup(optCOM.str);
  }

  /*ɸϥץ+إåν*/
  fpw=mssOpenFPW(optOTF.str,optZIP.set,0);
  mssWriteHeader(hdo,fpw);

/*----------------------------------------------------------------------------*/
/*ᥤ롼                                                              */
/*----------------------------------------------------------------------------*/
  rec=mssInitRec();
  while(EOF != mssReadRec(fpr,rec)){
    mssGV.inCnt++;
    mssWriteStr(rec->pnt,fpw);
    mssWriteRet(fpw);
    mssGV.outCnt++;
  } 
  mssFreeRec(rec);

/*----------------------------------------------------------------------------*/
/*եå&λ                                                       */
/*----------------------------------------------------------------------------*/
  mssWriteFooter(fpw);    /* եåν             */
  mssCloseFPR(fpr);       /* ϥեΥ     */
  mssCloseFPW(fpw);       /* ϥեΥ     */
  mssFreeHeader(hdi);     /* ϥإåΰ賫         */
  mssFreeHeader(hdo);     /* ϥإåΰ賫         */
  mssFreeOption(opt);     /* ץΰ賫         */
  mssShowEndMsg();        /* λå             */
  mssEnd(mssExitSuccess); /* λ                       */
  return(0);              /* to avoid warning message   */
}
